==> flutter_mylibrary-0.4.61.tar.gz: lib/base/getx/getx_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import '../../flutter_mylibrary.dart';
import '../base_view_state.dart';
import 'base_view_state_getx_controller.dart';


///该控制类用于model返回
abstract class GetxRequestModelController<T> extends BaseViewStateGetxController with BaseViewState{

  T data;


  void getData() async{
    data = await _request();

    if(viewState != ViewState.error){
      setIdle();
    }
    refreshController.finishRefresh();
  }


  @override
  void onReady() async{
    requestInfo = await getRequestInfo();
    getData();
  }


  ///获取主数据
  Future<T> _request() async{
    requestInfo = await getRequestInfo();

    if (viewState == ViewState.busy) {
      refreshController = EasyRefreshController();
    }

    getOtherData();

    await EasyDio().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: requestInfo?.publicMethod,
    ).then((res){
      try{
        if (isNotEmpty(res.data)) {
          data = requestInfo?.handleRes(res.data);
          onCompleted(data);
        }else{
          errorType = ViewStateErrorType.noDataError;
          setError(
              errorType: errorType,
          );
        }
      }catch(e){
        onError(e);

        errorType = ViewStateErrorType.jsonParsingError;

        setError(
            errorType: errorType,
            e: e
        );

        return null;
      }
    }, onError: (e){
      setError(
          errorType: errorType,
          e: e
      );
    });


    return data;
  }




  onCompleted(T data) {}


  ///获取一个公共的刷新控件
  Widget getEasyRefreshWidget({Widget emptyWidget, ViewStateModelWidgetBuilder<T> builder, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true, OnLoadCallback onLoad}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewStateModel: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh(
      emptyWidget: emptyErrorWidget,
      child: isEmpty(emptyErrorWidget)? builder(data) : Container(),
      onRefresh: isBusy? null : () async{
        getData();
      },
      onLoad: onLoad,
      controller: refreshController,
    );
  }

}

==> flutter_mylibrary-0.4.62.tar.gz: lib/base/getx/getx_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import '../../flutter_mylibrary.dart';
import '../base_view_state.dart';
import 'base_view_state_getx_controller.dart';


///该控制类用于model返回
abstract class GetxRequestModelController<T> extends BaseViewStateGetxController with BaseViewState{

  T data;


  void getData() async{
    data = await _request();

    if(viewState != ViewState.error){
      setIdle();
    }
    refreshController.finishRefresh();
  }


  @override
  void onReady() async{
    getData();
  }


  ///获取主数据
  Future<T> _request() async{

    beforeRequest();

    requestInfo = getRequestInfo();

    if (viewState == ViewState.busy) {
      refreshController = EasyRefreshController();
    }

    getOtherData();

    await EasyDio().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: requestInfo?.publicMethod,
    ).then((res){
      try{
        if (isNotEmpty(res.data)) {
          data = requestInfo?.handleRes(res.data);
          onCompleted(data);
        }else{
          errorType = ViewStateErrorType.noDataError;
          setError(
              errorType: errorType,
          );
        }
      }catch(e){
        onError(e);

        errorType = ViewStateErrorType.jsonParsingError;

        setError(
            errorType: errorType,
            e: e
        );

        return null;
      }
    }, onError: (e){
      setError(
          errorType: errorType,
          e: e
      );
    });


    return data;
  }




  onCompleted(T data) {}


  ///获取一个公共的刷新控件
  Widget getEasyRefreshWidget({Widget emptyWidget, ViewStateModelWidgetBuilder<T> builder, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true, OnLoadCallback onLoad}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewStateModel: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh(
      emptyWidget: emptyErrorWidget,
      child: isEmpty(emptyErrorWidget)? builder(data) : Container(),
      onRefresh: isBusy? null : () async{
        getData();
      },
      onLoad: onLoad,
      controller: refreshController,
    );
  }

}
